---
permalink: /support/contact/discord-support/ 
layout: support-contact
---

{% include form.html 
    form=site.data.support.tire_form 
    next="/support/payment/discord-support/"
    subject="Discord support" %}